@@ -57,26 +57,26 @@ from botocore.paginate import Paginator as Boto3Paginator
 
 from .literals import ServiceUpdateStatusType, SourceTypeType, UpdateActionStatusType
 from .type_defs import (
-    CacheClusterMessageResponseTypeDef,
-    CacheEngineVersionMessageResponseTypeDef,
-    CacheParameterGroupDetailsResponseTypeDef,
-    CacheParameterGroupsMessageResponseTypeDef,
-    CacheSecurityGroupMessageResponseTypeDef,
-    CacheSubnetGroupMessageResponseTypeDef,
-    DescribeEngineDefaultParametersResultResponseTypeDef,
-    DescribeGlobalReplicationGroupsResultResponseTypeDef,
-    DescribeSnapshotsListMessageResponseTypeDef,
-    DescribeUserGroupsResultResponseTypeDef,
-    DescribeUsersResultResponseTypeDef,
-    EventsMessageResponseTypeDef,
+    CacheClusterMessageTypeDef,
+    CacheEngineVersionMessageTypeDef,
+    CacheParameterGroupDetailsTypeDef,
+    CacheParameterGroupsMessageTypeDef,
+    CacheSecurityGroupMessageTypeDef,
+    CacheSubnetGroupMessageTypeDef,
+    DescribeEngineDefaultParametersResultTypeDef,
+    DescribeGlobalReplicationGroupsResultTypeDef,
+    DescribeSnapshotsListMessageTypeDef,
+    DescribeUserGroupsResultTypeDef,
+    DescribeUsersResultTypeDef,
+    EventsMessageTypeDef,
     FilterTypeDef,
     PaginatorConfigTypeDef,
-    ReplicationGroupMessageResponseTypeDef,
-    ReservedCacheNodeMessageResponseTypeDef,
-    ReservedCacheNodesOfferingMessageResponseTypeDef,
-    ServiceUpdatesMessageResponseTypeDef,
+    ReplicationGroupMessageTypeDef,
+    ReservedCacheNodeMessageTypeDef,
+    ReservedCacheNodesOfferingMessageTypeDef,
+    ServiceUpdatesMessageTypeDef,
     TimeRangeFilterTypeDef,
-    UpdateActionsMessageResponseTypeDef,
+    UpdateActionsMessageTypeDef,
 )
 
 __all__ = (
@@ -102,7 +102,7 @@ __all__ = (
 
 class DescribeCacheClustersPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheClusters)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheClusters)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elasticache/paginators.html#describecacheclusterspaginator)
     """
 
@@ -113,16 +113,16 @@ class DescribeCacheClustersPaginator(Boto3Paginator):
         ShowCacheNodeInfo: bool = None,
         ShowCacheClustersNotInReplicationGroups: bool = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[CacheClusterMessageResponseTypeDef]:
+    ) -> Iterator[CacheClusterMessageTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheClusters.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheClusters.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elasticache/paginators.html#describecacheclusterspaginator)
         """
 
 
 class DescribeCacheEngineVersionsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheEngineVersions)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheEngineVersions)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elasticache/paginators.html#describecacheengineversionspaginator)
     """
 
@@ -134,16 +134,16 @@ class DescribeCacheEngineVersionsPaginator(Boto3Paginator):
         CacheParameterGroupFamily: str = None,
         DefaultOnly: bool = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[CacheEngineVersionMessageResponseTypeDef]:
+    ) -> Iterator[CacheEngineVersionMessageTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheEngineVersions.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheEngineVersions.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elasticache/paginators.html#describecacheengineversionspaginator)
         """
 
 
 class DescribeCacheParameterGroupsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheParameterGroups)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheParameterGroups)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elasticache/paginators.html#describecacheparametergroupspaginator)
     """
 
@@ -152,16 +152,16 @@ class DescribeCacheParameterGroupsPaginator(Boto3Paginator):
         *,
         CacheParameterGroupName: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[CacheParameterGroupsMessageResponseTypeDef]:
+    ) -> Iterator[CacheParameterGroupsMessageTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheParameterGroups.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheParameterGroups.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elasticache/paginators.html#describecacheparametergroupspaginator)
         """
 
 
 class DescribeCacheParametersPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheParameters)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheParameters)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elasticache/paginators.html#describecacheparameterspaginator)
     """
 
@@ -171,61 +171,61 @@ class DescribeCacheParametersPaginator(Boto3Paginator):
         CacheParameterGroupName: str,
         Source: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[CacheParameterGroupDetailsResponseTypeDef]:
+    ) -> Iterator[CacheParameterGroupDetailsTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheParameters.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheParameters.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elasticache/paginators.html#describecacheparameterspaginator)
         """
 
 
 class DescribeCacheSecurityGroupsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheSecurityGroups)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheSecurityGroups)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elasticache/paginators.html#describecachesecuritygroupspaginator)
     """
 
     def paginate(
         self, *, CacheSecurityGroupName: str = None, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[CacheSecurityGroupMessageResponseTypeDef]:
+    ) -> Iterator[CacheSecurityGroupMessageTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheSecurityGroups.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheSecurityGroups.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elasticache/paginators.html#describecachesecuritygroupspaginator)
         """
 
 
 class DescribeCacheSubnetGroupsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheSubnetGroups)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheSubnetGroups)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elasticache/paginators.html#describecachesubnetgroupspaginator)
     """
 
     def paginate(
         self, *, CacheSubnetGroupName: str = None, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[CacheSubnetGroupMessageResponseTypeDef]:
+    ) -> Iterator[CacheSubnetGroupMessageTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheSubnetGroups.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheSubnetGroups.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elasticache/paginators.html#describecachesubnetgroupspaginator)
         """
 
 
 class DescribeEngineDefaultParametersPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/elasticache.html#ElastiCache.Paginator.DescribeEngineDefaultParameters)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeEngineDefaultParameters)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elasticache/paginators.html#describeenginedefaultparameterspaginator)
     """
 
     def paginate(
         self, *, CacheParameterGroupFamily: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[DescribeEngineDefaultParametersResultResponseTypeDef]:
+    ) -> Iterator[DescribeEngineDefaultParametersResultTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/elasticache.html#ElastiCache.Paginator.DescribeEngineDefaultParameters.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeEngineDefaultParameters.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elasticache/paginators.html#describeenginedefaultparameterspaginator)
         """
 
 
 class DescribeEventsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/elasticache.html#ElastiCache.Paginator.DescribeEvents)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeEvents)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elasticache/paginators.html#describeeventspaginator)
     """
 
@@ -238,16 +238,16 @@ class DescribeEventsPaginator(Boto3Paginator):
         EndTime: Union[datetime, str] = None,
         Duration: int = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[EventsMessageResponseTypeDef]:
+    ) -> Iterator[EventsMessageTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/elasticache.html#ElastiCache.Paginator.DescribeEvents.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeEvents.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elasticache/paginators.html#describeeventspaginator)
         """
 
 
 class DescribeGlobalReplicationGroupsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/elasticache.html#ElastiCache.Paginator.DescribeGlobalReplicationGroups)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeGlobalReplicationGroups)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elasticache/paginators.html#describeglobalreplicationgroupspaginator)
     """
 
@@ -257,31 +257,31 @@ class DescribeGlobalReplicationGroupsPaginator(Boto3Paginator):
         GlobalReplicationGroupId: str = None,
         ShowMemberInfo: bool = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[DescribeGlobalReplicationGroupsResultResponseTypeDef]:
+    ) -> Iterator[DescribeGlobalReplicationGroupsResultTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/elasticache.html#ElastiCache.Paginator.DescribeGlobalReplicationGroups.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeGlobalReplicationGroups.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elasticache/paginators.html#describeglobalreplicationgroupspaginator)
         """
 
 
 class DescribeReplicationGroupsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/elasticache.html#ElastiCache.Paginator.DescribeReplicationGroups)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeReplicationGroups)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elasticache/paginators.html#describereplicationgroupspaginator)
     """
 
     def paginate(
         self, *, ReplicationGroupId: str = None, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ReplicationGroupMessageResponseTypeDef]:
+    ) -> Iterator[ReplicationGroupMessageTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/elasticache.html#ElastiCache.Paginator.DescribeReplicationGroups.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeReplicationGroups.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elasticache/paginators.html#describereplicationgroupspaginator)
         """
 
 
 class DescribeReservedCacheNodesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/elasticache.html#ElastiCache.Paginator.DescribeReservedCacheNodes)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeReservedCacheNodes)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elasticache/paginators.html#describereservedcachenodespaginator)
     """
 
@@ -295,16 +295,16 @@ class DescribeReservedCacheNodesPaginator(Boto3Paginator):
         ProductDescription: str = None,
         OfferingType: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ReservedCacheNodeMessageResponseTypeDef]:
+    ) -> Iterator[ReservedCacheNodeMessageTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/elasticache.html#ElastiCache.Paginator.DescribeReservedCacheNodes.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeReservedCacheNodes.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elasticache/paginators.html#describereservedcachenodespaginator)
         """
 
 
 class DescribeReservedCacheNodesOfferingsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/elasticache.html#ElastiCache.Paginator.DescribeReservedCacheNodesOfferings)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeReservedCacheNodesOfferings)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elasticache/paginators.html#describereservedcachenodesofferingspaginator)
     """
 
@@ -317,16 +317,16 @@ class DescribeReservedCacheNodesOfferingsPaginator(Boto3Paginator):
         ProductDescription: str = None,
         OfferingType: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ReservedCacheNodesOfferingMessageResponseTypeDef]:
+    ) -> Iterator[ReservedCacheNodesOfferingMessageTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/elasticache.html#ElastiCache.Paginator.DescribeReservedCacheNodesOfferings.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeReservedCacheNodesOfferings.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elasticache/paginators.html#describereservedcachenodesofferingspaginator)
         """
 
 
 class DescribeServiceUpdatesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/elasticache.html#ElastiCache.Paginator.DescribeServiceUpdates)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeServiceUpdates)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elasticache/paginators.html#describeserviceupdatespaginator)
     """
 
@@ -336,16 +336,16 @@ class DescribeServiceUpdatesPaginator(Boto3Paginator):
         ServiceUpdateName: str = None,
         ServiceUpdateStatus: List[ServiceUpdateStatusType] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ServiceUpdatesMessageResponseTypeDef]:
+    ) -> Iterator[ServiceUpdatesMessageTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/elasticache.html#ElastiCache.Paginator.DescribeServiceUpdates.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeServiceUpdates.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elasticache/paginators.html#describeserviceupdatespaginator)
         """
 
 
 class DescribeSnapshotsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/elasticache.html#ElastiCache.Paginator.DescribeSnapshots)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeSnapshots)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elasticache/paginators.html#describesnapshotspaginator)
     """
 
@@ -358,16 +358,16 @@ class DescribeSnapshotsPaginator(Boto3Paginator):
         SnapshotSource: str = None,
         ShowNodeGroupConfig: bool = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[DescribeSnapshotsListMessageResponseTypeDef]:
+    ) -> Iterator[DescribeSnapshotsListMessageTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/elasticache.html#ElastiCache.Paginator.DescribeSnapshots.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeSnapshots.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elasticache/paginators.html#describesnapshotspaginator)
         """
 
 
 class DescribeUpdateActionsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/elasticache.html#ElastiCache.Paginator.DescribeUpdateActions)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeUpdateActions)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elasticache/paginators.html#describeupdateactionspaginator)
     """
 
@@ -383,31 +383,31 @@ class DescribeUpdateActionsPaginator(Boto3Paginator):
         UpdateActionStatus: List[UpdateActionStatusType] = None,
         ShowNodeLevelUpdateStatus: bool = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[UpdateActionsMessageResponseTypeDef]:
+    ) -> Iterator[UpdateActionsMessageTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/elasticache.html#ElastiCache.Paginator.DescribeUpdateActions.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeUpdateActions.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elasticache/paginators.html#describeupdateactionspaginator)
         """
 
 
 class DescribeUserGroupsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/elasticache.html#ElastiCache.Paginator.DescribeUserGroups)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeUserGroups)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elasticache/paginators.html#describeusergroupspaginator)
     """
 
     def paginate(
         self, *, UserGroupId: str = None, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[DescribeUserGroupsResultResponseTypeDef]:
+    ) -> Iterator[DescribeUserGroupsResultTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/elasticache.html#ElastiCache.Paginator.DescribeUserGroups.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeUserGroups.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elasticache/paginators.html#describeusergroupspaginator)
         """
 
 
 class DescribeUsersPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/elasticache.html#ElastiCache.Paginator.DescribeUsers)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeUsers)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elasticache/paginators.html#describeuserspaginator)
     """
 
@@ -418,8 +418,8 @@ class DescribeUsersPaginator(Boto3Paginator):
         UserId: str = None,
         Filters: List["FilterTypeDef"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[DescribeUsersResultResponseTypeDef]:
+    ) -> Iterator[DescribeUsersResultTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/elasticache.html#ElastiCache.Paginator.DescribeUsers.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeUsers.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elasticache/paginators.html#describeuserspaginator)
         """
